@@ -2,17 +2,15 @@ package com.fasterxml.jackson.jr.annotationsupport;
 
 import java.util.Arrays;
 
+import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonValue;
 import com.fasterxml.jackson.jr.ob.JSON;
 
 import junit.framework.TestCase;
 
 public abstract class ASTestBase extends TestCase
 {
-    protected enum ABC { A, B, C; }
-
-    protected enum ABCRename { @JsonProperty("A1") A, @JsonProperty("B1") B, C; }
-
     protected static class NameBean {
         protected String first, last;
 
