@@ -31,7 +31,7 @@ import com.fasterxml.jackson.jr.ob.impl.*;
  * <li>{@link URL}</li>
  * <li>{@link File}</li>
  * </ul>
- * 
+ *
  */
 @SuppressWarnings("resource")
 public class JSON implements Versioned
@@ -42,308 +42,345 @@ public class JSON implements Versioned
      */
     public enum Feature
     {
-       /*
-       /**********************************************************************
-       /* Read-related features that do not affect caching
-       /**********************************************************************
-        */
+        /*
+        /**********************************************************************
+        /* Read-related features that do not affect caching
+        /**********************************************************************
+         */
 
-       /**
-        * When reading JSON Numbers, should {@link java.math.BigDecimal} be used
-        * for floating-point numbers; or should {@link java.lang.Double} be used.
-        * Trade-off is between accuracy -- only {@link java.math.BigDecimal} is
-        * guaranteed to store the EXACT decimal value parsed -- and performance
-        * ({@link java.lang.Double} is typically faster to parse).
-        *<p>
-        * Default setting is <code>false</code>, meaning that {@link java.lang.Double}
-        * is used.
-        */
-       USE_BIG_DECIMAL_FOR_FLOATS(false),
+        /**
+         * When reading JSON Numbers, should {@link java.math.BigDecimal} be used
+         * for floating-point numbers; or should {@link java.lang.Double} be used.
+         * Trade-off is between accuracy -- only {@link java.math.BigDecimal} is
+         * guaranteed to store the EXACT decimal value parsed -- and performance
+         * ({@link java.lang.Double} is typically faster to parse).
+         *<p>
+         * Default setting is <code>false</code>, meaning that {@link java.lang.Double}
+         * is used.
+         */
+        USE_BIG_DECIMAL_FOR_FLOATS(false),
 
-       /**
-        * When reading JSON Arrays, should matching Java value be of type
-        * <code>Object[]</code> (true) or {@link java.util.List} (false)?
-        *<p>
-        * Default setting is <code>false</code>, meaning that JSON Arrays
-        * are bound to {@link java.util.List}s.
-        */
-       READ_JSON_ARRAYS_AS_JAVA_ARRAYS(false),
+        /**
+         * When reading JSON Arrays, should matching Java value be of type
+         * <code>Object[]</code> (true) or {@link java.util.List} (false)?
+         *<p>
+         * Default setting is <code>false</code>, meaning that JSON Arrays
+         * are bound to {@link java.util.List}s.
+         */
+        READ_JSON_ARRAYS_AS_JAVA_ARRAYS(false),
 
-       /**
-        * This feature can be enabled to reduce memory usage for use cases where
-        * resulting container objects ({@link java.util.Map}s and {@link java.util.Collection}s)
-        * do not need to mutable (that is, their contents can not changed).
-        * If set, reader is allowed to construct immutable (read-only)
-        * container objects; and specifically empty {@link java.util.Map}s and
-        * {@link java.util.Collection}s can be used to reduce number of
-        * objects allocated. In addition, sizes of non-empty containers can
-        * be trimmed to exact size.
-        *<p>
-        * Default setting is <code>false</code>, meaning that reader will have to
-        * construct mutable container instance when reading.
-        */
-       READ_ONLY(false),
+        /**
+         * This feature can be enabled to reduce memory usage for use cases where
+         * resulting container objects ({@link java.util.Map}s and {@link java.util.Collection}s)
+         * do not need to mutable (that is, their contents can not changed).
+         * If set, reader is allowed to construct immutable (read-only)
+         * container objects; and specifically empty {@link java.util.Map}s and
+         * {@link java.util.Collection}s can be used to reduce number of
+         * objects allocated. In addition, sizes of non-empty containers can
+         * be trimmed to exact size.
+         *<p>
+         * Default setting is <code>false</code>, meaning that reader will have to
+         * construct mutable container instance when reading.
+         */
+        READ_ONLY(false),
 
-       /**
-        * This feature can be used to indicate that the reader should preserve
-        * order of the properties same as what input document has.
-        * Note that it is up to {@link com.fasterxml.jackson.jr.ob.api.MapBuilder}
-        * to support this feature; custom implementations may ignore the setting.
-        *<p>
-        * Default setting is <code>true</code>, meaning that reader is expected to try to
-        * preserve ordering of fields read.
-        */
-       PRESERVE_FIELD_ORDERING(true),
+        /**
+         * This feature can be used to indicate that the reader should preserve
+         * order of the properties same as what input document has.
+         * Note that it is up to {@link com.fasterxml.jackson.jr.ob.api.MapBuilder}
+         * to support this feature; custom implementations may ignore the setting.
+         *<p>
+         * Default setting is <code>true</code>, meaning that reader is expected to try to
+         * preserve ordering of fields read.
+         */
+        PRESERVE_FIELD_ORDERING(true),
 
-       /**
-        * This feature determines whether {@link Map} instances constructed use
-        * deferred materialization (as implemented by {@link DeferredMap}), in case
-        * user has not specified custom {@link Map} implementation.
-        * Enabling feature typically reduces initial value read time and moves
-        * overhead to actual access of contents (materialization occurs when first
-        * key or value access happens); this makes sense when only a subset of
-        * data is accessed. Conversely, when traversing full object hierarchy, it
-        * makes sense to disable this feature.
-        *<p>
-        * Default setting is <code>true</code>, meaning that reader is expected to try to
-        */
-       USE_DEFERRED_MAPS(true),
+        /**
+         * This feature determines whether {@link Map} instances constructed use
+         * deferred materialization (as implemented by {@link DeferredMap}), in case
+         * user has not specified custom {@link Map} implementation.
+         * Enabling feature typically reduces initial value read time and moves
+         * overhead to actual access of contents (materialization occurs when first
+         * key or value access happens); this makes sense when only a subset of
+         * data is accessed. Conversely, when traversing full object hierarchy, it
+         * makes sense to disable this feature.
+         *<p>
+         * Default setting is <code>true</code>, meaning that reader is expected to try to
+         */
+        USE_DEFERRED_MAPS(true),
 
-       /**
-        * When encountering duplicate keys for JSON Objects, should an exception
-        * be thrown or not? If exception is not thrown, <b>the last</b> instance
-        * from input document will be used.
-        *<p>
-        * Default setting is <code>true</code>, meaning that a
-        * {@link JSONObjectException} will be thrown if duplicates are encountered.
-        */
-       FAIL_ON_DUPLICATE_MAP_KEYS(true),
+        /**
+         * When encountering duplicate keys for JSON Objects, should an exception
+         * be thrown or not? If exception is not thrown, <b>the last</b> instance
+         * from input document will be used.
+         *<p>
+         * Default setting is <code>true</code>, meaning that a
+         * {@link JSONObjectException} will be thrown if duplicates are encountered.
+         */
+        FAIL_ON_DUPLICATE_MAP_KEYS(true),
 
-       /**
-        * When encountering a JSON Object property name for which there is no
-        * matching Bean property, should an exception be thrown (true),
-        * or should JSON Property value be quietly skipped (false)?
-        *<p>
-        * Default setting is <code>false</code>, meaning that unmappable
-        * JSON Object properties will simply be ignored.
-        */
-       FAIL_ON_UNKNOWN_BEAN_PROPERTY(false),
+        /**
+         * When encountering a JSON Object property name for which there is no
+         * matching Bean property, should an exception be thrown (true),
+         * or should JSON Property value be quietly skipped (false)?
+         *<p>
+         * Default setting is <code>false</code>, meaning that unmappable
+         * JSON Object properties will simply be ignored.
+         */
+        FAIL_ON_UNKNOWN_BEAN_PROPERTY(false),
 
-       /*
-       /**********************************************************************
-       /* Write-related features that do not affect caching
-       /**********************************************************************
-        */
+        /*
+        /**********************************************************************
+        /* Write-related features that do not affect caching
+        /**********************************************************************
+         */
 
-       /**
-        * Feature that defines what to do with {@link java.util.Map} entries and Java Bean
-        * properties that have null as value: if enabled, they will be written out normally;
-        * if disabled, such entries and properties will be ignored.
-        *<p>
-        * Default setting is <code>false</code> so that any null-valued properties
-        * are ignored during serialization.
-        */
-       WRITE_NULL_PROPERTIES(false),
+        /**
+         * Feature that defines what to do with {@link java.util.Map} entries and Java Bean
+         * properties that have null as value: if enabled, they will be written out normally;
+         * if disabled, such entries and properties will be ignored.
+         *<p>
+         * Default setting is <code>false</code> so that any null-valued properties
+         * are ignored during serialization.
+         */
+        WRITE_NULL_PROPERTIES(false),
 
-       /**
-        * Feature that determines whether Enum values are written using
-        * numeric index (true), or String representation from calling
-        * {@link Enum#toString()} (false).
-        *<p>
-        * Feature is disabled by default,
-        * so that Enums are serialized as JSON Strings.
-        */
-       WRITE_ENUMS_USING_INDEX(false),
+        /**
+         * Feature that determines whether Enum values are written using
+         * numeric index (true), or String representation from calling
+         * {@link Enum#toString()} (false).
+         *<p>
+         * Feature is disabled by default,
+         * so that Enums are serialized as JSON Strings.
+         */
+        WRITE_ENUMS_USING_INDEX(false),
 
-       /**
-        * Feature that determines whether Date (and date/time) values
-        * (and Date-based things like {@link java.util.Calendar}s) are to be
-        * serialized as numeric timestamps (true),
-        * or using a textual representation (false)
-        *<p>
-        * Feature is disabled by default, so that date/time values are
-        * serialized as text, NOT timestamp.
-        *
-        * @since 2.7
-        */
-       WRITE_DATES_AS_TIMESTAMP(false),
-       
-       /**
-        * Feature that can be enabled to use "pretty-printing", basic indentation
-        * to make resulting JSON easier to read by humans by adding white space
-        * such as line feeds and indentation.
-        *<p>
-        * Default setting is <code>false</code> so that no pretty-printing is done
-        * (unless explicitly constructed with a pretty printer object)
-        */
-       PRETTY_PRINT_OUTPUT(false),
+        /**
+         * Feature that determines whether Date (and date/time) values
+         * (and Date-based things like {@link java.util.Calendar}s) are to be
+         * serialized as numeric timestamps (true),
+         * or using a textual representation (false)
+         *<p>
+         * Feature is disabled by default, so that date/time values are
+         * serialized as text, NOT timestamp.
+         *
+         * @since 2.7
+         */
+        WRITE_DATES_AS_TIMESTAMP(false),
 
-       /**
-        * Feature that determines whether <code>JsonGenerator.flush()</code> is
-        * called after <code>write()</code> method <b>that takes JsonGenerator
-        * as an argument</b> completes (that is, does NOT affect methods
-        * that use other destinations).
-        * This usually makes sense; but there are cases where flushing
-        * should not be forced: for example when underlying stream is
-        * compressing and flush() causes compression state to be flushed
-        * (which occurs with some compression codecs).
-        *<p>
-        * Feature is enabled by default.
-        */
-       FLUSH_AFTER_WRITE_VALUE(true),
+        /**
+         * Feature that can be enabled to use "pretty-printing", basic indentation
+         * to make resulting JSON easier to read by humans by adding white space
+         * such as line feeds and indentation.
+         *<p>
+         * Default setting is <code>false</code> so that no pretty-printing is done
+         * (unless explicitly constructed with a pretty printer object)
+         */
+        PRETTY_PRINT_OUTPUT(false),
 
-       /**
-        * Feature that determines what happens when we encounter a value of
-        * unrecognized type for which we do not have standard handler: if enabled,
-        * will throw a {@link JSONObjectException}, if disabled simply
-        * calls {@link Object#toString} and uses that JSON String as serialization.
-        *<p>
-        * NOTE: if {@link #HANDLE_JAVA_BEANS} is enabled, this setting typically
-        * has no effect, since otherwise unknown types are recognized as
-        * Bean types.
-        *
-        *<p>
-        * Feature is disabled by default
-        * so that no exceptions are thrown.
-        */
-       FAIL_ON_UNKNOWN_TYPE_WRITE(false),
+        /**
+         * Feature that determines whether <code>JsonGenerator.flush()</code> is
+         * called after <code>write()</code> method <b>that takes JsonGenerator
+         * as an argument</b> completes (that is, does NOT affect methods
+         * that use other destinations).
+         * This usually makes sense; but there are cases where flushing
+         * should not be forced: for example when underlying stream is
+         * compressing and flush() causes compression state to be flushed
+         * (which occurs with some compression codecs).
+         *<p>
+         * Feature is enabled by default.
+         */
+        FLUSH_AFTER_WRITE_VALUE(true),
 
-       /*
-       /**********************************************************************
-       /* Features that affect introspection and thereby affect caching
-       /**********************************************************************
-        */
+        /**
+         * Feature that determines what happens when we encounter a value of
+         * unrecognized type for which we do not have standard handler: if enabled,
+         * will throw a {@link JSONObjectException}, if disabled simply
+         * calls {@link Object#toString} and uses that JSON String as serialization.
+         *<p>
+         * NOTE: if {@link #HANDLE_JAVA_BEANS} is enabled, this setting typically
+         * has no effect, since otherwise unknown types are recognized as
+         * Bean types.
+         *
+         *<p>
+         * Feature is disabled by default
+         * so that no exceptions are thrown.
+         */
+        FAIL_ON_UNKNOWN_TYPE_WRITE(false),
 
-       /**
-        * Feature that determines whether Bean types (Java objects with
-        * getters and setters that expose state to serialize) will be
-        * recognized and handled or not.
-        * When enabled, any types that are not recognized as standard JDK
-        * data structures, primitives or wrapper values will be introspected
-        * and handled as Java Beans (can be read/written as long as JSON
-        * matches properties discovered); when disabled, they may only be serialized
-        * (using {@link Object#toString} method), and can not be deserialized.
-        *<p>
-        * Feature is enabled by default, but can be disabled do avoid use
-        * of Bean reflection for cases where it is not desired.
-        */
-       HANDLE_JAVA_BEANS(true, true),
+        /*
+        /**********************************************************************
+        /* Features that affect introspection and thereby affect caching
+        /**********************************************************************
+         */
 
-       /**
-        * Feature that determines whether "read-only" properties of Beans
-        * (properties that only have a getter but no matching setter) are
-        * to be included in Bean serialization or not; if disabled,
-        * only properties have have both setter and getter are serialized.
-        * Note that feature is only used if {@link #HANDLE_JAVA_BEANS}
-        * is also enabled.
-        *<p>
-        * Feature is enabled by default,
-        * so that all Bean properties are serialized.
-        */
-       WRITE_READONLY_BEAN_PROPERTIES(true, true),
-       
-       /**
-        * Feature that determines whether access to {@link java.lang.reflect.Method}s and
-        * {@link java.lang.reflect.Constructor}s that are used with dynamically
-        * introspected Beans may be forced using
-        * {@link java.lang.reflect.AccessibleObject#setAccessible} or not.
-        *<p>
-        * Feature is enabled by default, so that access may be forced.
-        */
-       FORCE_REFLECTION_ACCESS(true, true),
+        /**
+         * Feature that determines whether Bean types (Java objects with
+         * getters and setters that expose state to serialize) will be
+         * recognized and handled or not.
+         * When enabled, any types that are not recognized as standard JDK
+         * data structures, primitives or wrapper values will be introspected
+         * and handled as Java Beans (can be read/written as long as JSON
+         * matches properties discovered); when disabled, they may only be serialized
+         * (using {@link Object#toString} method), and can not be deserialized.
+         *<p>
+         * Feature is enabled by default, but can be disabled do avoid use
+         * of Bean reflection for cases where it is not desired.
+         */
+        HANDLE_JAVA_BEANS(true, true),
 
-       /**
-        * Whether "is-getters" (like <code>public boolean isValuable()</code>) are detected
-        * for use or not. Note that in addition to naming, and lack of arguments, return
-        * value also has to be <code>boolean</code> or <code>java.lang.Boolean</code>.
-        *
-        * @since 2.5
-        */
-       USE_IS_GETTERS(true, true),
-       
-       /**
-        * Feature that enables use of public fields instead of setters and getters,
-        * in cases where no setter/getter is available.
-        *<p>
-        * Feature is <b>enabled</b> by default since 2.10 (but was <b>disabled</b> for
-        * 2.8 and 2.9), so public fields are discovered by default.
-        *
-        * @since 2.8 (enabled by default since 2.10)
-        */
-       USE_FIELDS(true, true),
+        /**
+         * Feature that determines whether "read-only" properties of Beans
+         * (properties that only have a getter but no matching setter) are
+         * to be included in Bean serialization or not; if disabled,
+         * only properties have have both setter and getter are serialized.
+         * Note that feature is only used if {@link #HANDLE_JAVA_BEANS}
+         * is also enabled.
+         *<p>
+         * Feature is enabled by default,
+         * so that all Bean properties are serialized.
+         */
+        WRITE_READONLY_BEAN_PROPERTIES(true, true),
+
+        /**
+         * Feature that determines whether access to {@link java.lang.reflect.Method}s and
+         * {@link java.lang.reflect.Constructor}s that are used with dynamically
+         * introspected Beans may be forced using
+         * {@link java.lang.reflect.AccessibleObject#setAccessible} or not.
+         *<p>
+         * Feature is enabled by default, so that access may be forced.
+         */
+        FORCE_REFLECTION_ACCESS(true, true),
+
+        /**
+         * Whether "is-getters" (like <code>public boolean isValuable()</code>) are detected
+         * for use or not. Note that in addition to naming, and lack of arguments, return
+         * value also has to be <code>boolean</code> or <code>java.lang.Boolean</code>.
+         *
+         * @since 2.5
+         */
+        USE_IS_GETTERS(true, true),
+
+        /**
+         * Feature that enables use of public fields instead of setters and getters,
+         * in cases where no setter/getter is available.
+         *<p>
+         * Feature is <b>enabled</b> by default since 2.10 (but was <b>disabled</b> for
+         * 2.8 and 2.9), so public fields are discovered by default.
+         *
+         * @since 2.8 (enabled by default since 2.10)
+         */
+        USE_FIELDS(true, true),
+
+        /**
+         * Feature that enables serialization and deserialization of non-final static fields.
+         *<p>
+         * Feature did not exist, but was implicitly <b>enabled</b> by default. <b>disabled</b> for
+         * 2.13).
+         *
+         * @since 2.13
+         */
+        INCLUDE_STATIC_FIELDS(false, true),
+
+        /**
+         * Feature that will allow for more forgiving deserialization of incoming JSON. If enabled,
+         * the bean properties will be matched using their lower-case equivalents, meaning that any
+         * case-combination (incoming and matching names are canonicalized by lower-casing) should work.
+         * <p>
+         * Note that there is additional performance overhead since incoming property names need to be lower-cased
+         * before comparison, for cases where there are upper-case letters. Overhead for names that are already
+         * lower-case should be negligible however.
+         *<p>
+         * Feature is <b>disabled</b> by default.
+         *
+         * @since 2.13
+         */
+        ACCEPT_CASE_INSENSITIVE_PROPERTIES(false, true),
+
+        /**
+         * Feature that determines if Enum deserialization should be case sensitive or not. If enabled,
+         * Enum deserialization will ignore case, that is, case of incoming String value and enum id
+         * (dependant on other settings, either `name()`, `toString()`, or explicit override) do not need to
+         * match.
+         *<p>
+         * Feature is <b>disabled</b> by default.
+         *
+         * @since 2.13
+         */
+        ACCEPT_CASE_INSENSITIVE_ENUMS(false, true)
        ;
 
-       /*
-       /**********************************************************************
-       /* Enum impl
-       /**********************************************************************
-        */
+        /*
+        /**********************************************************************
+        /* Enum impl
+        /**********************************************************************
+         */
 
-       private final boolean _defaultState;
+        private final boolean _defaultState;
 
-       /**
-        * Flag for features that affect caching of readers, writers,
-        * and changing of which needs to result in flushing.
-        *
-        * @since 2.8
-        */
-       private final boolean _affectsCaching;
+        /**
+         * Flag for features that affect caching of readers, writers,
+         * and changing of which needs to result in flushing.
+         *
+         * @since 2.8
+         */
+        private final boolean _affectsCaching;
 
-       private final int _mask;
+        private final int _mask;
 
-       private Feature(boolean defaultState) {
-           this(defaultState, false);
-       }
+        private Feature(boolean defaultState) {
+            this(defaultState, false);
+        }
 
-       private Feature(boolean defaultState, boolean affectsCaching) {
-           _defaultState = defaultState;
-           _affectsCaching = affectsCaching;
-           _mask = (1 << ordinal());
-       }
+        private Feature(boolean defaultState, boolean affectsCaching) {
+            _defaultState = defaultState;
+            _affectsCaching = affectsCaching;
+            _mask = (1 << ordinal());
+        }
 
-       public static int defaults()
-       {
-           int flags = 0;
-           for (Feature value : values()) {
-               if (value.enabledByDefault()) {
-                   flags |= value.mask();
-               }
-           }
-           return flags;
-       }
+        public static int defaults()
+        {
+            int flags = 0;
+            for (Feature value : values()) {
+                if (value.enabledByDefault()) {
+                    flags |= value.mask();
+                }
+            }
+            return flags;
+        }
 
-       /**
-        * Method for calculating bitset of features that force flushing of
-        * POJO handler caches.
-        *
-        * @since 2.8
-        */
-       public static int cacheBreakers()
-       {
-           int flags = 0;
-           for (Feature value : values()) {
-               if (value.affectsCaching()) {
-                   flags |= value.mask();
-               }
-           }
-           return flags;
-       }
+        /**
+         * Method for calculating bitset of features that force flushing of
+         * POJO handler caches.
+         *
+         * @since 2.8
+         */
+        public static int cacheBreakers()
+        {
+            int flags = 0;
+            for (Feature value : values()) {
+                if (value.affectsCaching()) {
+                    flags |= value.mask();
+                }
+            }
+            return flags;
+        }
 
-       public final boolean enabledByDefault() { return _defaultState; }
-       public final boolean affectsCaching() { return _affectsCaching; }
+        public final boolean enabledByDefault() { return _defaultState; }
+        public final boolean affectsCaching() { return _affectsCaching; }
 
-       public final int mask() { return _mask; }
+        public final int mask() { return _mask; }
 
-       public final boolean isDisabled(int flags) {
-           return (flags & _mask) == 0;
-       }
-       public final boolean isEnabled(int flags) {
-           return (flags & _mask) != 0;
-       }
+        public final boolean isDisabled(int flags) {
+            return (flags & _mask) == 0;
+        }
+        public final boolean isEnabled(int flags) {
+            return (flags & _mask) != 0;
+        }
     }
 
     // Important: has to come before 'std' instance, since it refers to it
-    private final static int DEFAULT_FEATURES = Feature.defaults();
+    final static int DEFAULT_FEATURES = Feature.defaults();
 
     public final static int CACHE_FLAGS = Feature.cacheBreakers();
 
@@ -422,7 +459,7 @@ public class JSON implements Versioned
         protected PrettyPrinter _prettyPrinter;
 
         // Configuration, helper objects
-        
+
         protected final JsonFactory _streamFactory;
         protected TreeCodec _treeCodec;
 
@@ -502,7 +539,7 @@ public class JSON implements Versioned
         }
 
         // // // Mutators, helper objects
-        
+
         /**
          * Method for specifying {@link PrettyPrinter} {@link JSON} to be built
          * should use on serialization.
@@ -732,7 +769,7 @@ public class JSON implements Versioned
     public ObjectCodec asCodec() {
         return new JSONAsObjectCodec(this);
     }
-    
+
     /*
     /**********************************************************************
     /* Versioned
@@ -785,7 +822,7 @@ public class JSON implements Versioned
         }
         return _with(f);
     }
-    
+
     /**
      * Mutant factory for constructing an instance with specified features
      * enabled.
@@ -825,7 +862,7 @@ public class JSON implements Versioned
         //    changes
         JSONReader r = _reader.withCacheCheck(features);
         JSONWriter w = _writer.withCacheCheck(features);
-        
+
         return _with(features, _jsonFactory, _treeCodec,
                 r, w, _prettyPrinter);
     }
@@ -839,14 +876,14 @@ public class JSON implements Versioned
     /**
      * Mutant factory method for constructing new instance with specified {@link JsonFactory}
      * if different from currently configured one (if not, return {@code this} as-is)
-     * 
+     *
      * @param f Jackson core format factory to use for low-level decoding/encoding
      *
      * @return New instance with specified factory (if not same as currently configured);
      *   {@code this} otherwise.
      *
      * @deprecated Since 2.11 should not try changing underlying stream factory but create
-     *   a new instance if necessary: method will be removed from 3.0 at latest 
+     *   a new instance if necessary: method will be removed from 3.0 at latest
      */
     @Deprecated
     public JSON with(JsonFactory f) {
@@ -966,7 +1003,7 @@ public class JSON implements Versioned
     /* Methods sub-classes must override
     /**********************************************************************
      */
-    
+
     protected JSON _with(int features,
             JsonFactory jsonF, TreeCodec trees,
             JSONReader reader, JSONWriter writer,
@@ -992,7 +1029,7 @@ public class JSON implements Versioned
     public final boolean isEnabled(Feature f) {
         return (f.mask() & _features) != 0;
     }
-    
+
     /*
     /**********************************************************************
     /* Public factory methods for parsers, generators
@@ -1122,7 +1159,7 @@ public class JSON implements Versioned
     public <C extends Collection<Object>> CollectionComposer<?,C> composeCollection(C collection) {
         return new CollectionComposer<ComposerBase,C>(collection);
     }
-    
+
     public MapComposer<?> composeMap() {
         return composeMap(new LinkedHashMap<String,Object>());
     }
@@ -1294,7 +1331,7 @@ public class JSON implements Versioned
             return _closeWithError(p, e);
         }
     }
-    
+
     /**
      * Read method that will take given JSON Source (of one of supported types),
      * read contents and map it to one of simple mappings ({@link java.util.Map}
@@ -1476,7 +1513,7 @@ public class JSON implements Versioned
           }
          return (T) _treeCodec.createArrayNode();
     }
-    
+
     /**
      * Convenience method, equivalent to:
      *<pre>
@@ -1527,7 +1564,7 @@ public class JSON implements Versioned
     /* Internal methods, reading
     /**********************************************************************
      */
-    
+
     protected JSONReader _readerForOperation(JsonParser p) {
         return _reader.perOperationInstance(_features, _valueReaderLocator, _treeCodec, p);
     }
@@ -1585,7 +1622,7 @@ public class JSON implements Versioned
     /* Internal methods, other
     /**********************************************************************
      */
-    
+
     protected JsonGenerator _config(JsonGenerator g)
     {
         // First, possible pretty printing
@@ -1629,7 +1666,7 @@ public class JSON implements Versioned
         }
         throw new IOException(e); // should never occur
     }
-    
+
     protected void _noTreeCodec(String msg) {
          throw new IllegalStateException("JSON instance does not have configured `TreeCodec` to "+msg);
     }
@@ -1641,7 +1678,7 @@ public class JSON implements Versioned
      */
 
     /**
-     * Extension context implementation used when 
+     * Extension context implementation used when
      */
     private static class ExtContextImpl extends ExtensionContext {
         final Builder _builder;
