@@ -64,7 +64,7 @@ public class ValueReaderLocator
     /* Caching
     /**********************************************************************
      */
-    
+
     /**
      * Set of {@link ValueReader}s that we have resolved
      */
@@ -100,7 +100,7 @@ public class ValueReaderLocator
     /* Instance state, caching
     /**********************************************************************
      */
-    
+
     /**
      * Reusable lookup key; only used by per-thread instances.
      */
@@ -143,14 +143,14 @@ public class ValueReaderLocator
         // create new cache as there may be custom writers:
         _knownReaders = new ConcurrentHashMap<ClassKey, ValueReader>(10, 0.75f, 2);
         _readerLock = new Object();
-        
+
         _features = base._features;
         _readContext = base._readContext;
         _readerProvider = rwp;
         _readerModifier = rwm;
         _typeResolver = base._typeResolver;
     }
-    
+
     public final static ValueReaderLocator blueprint(ReaderWriterProvider rwp, ReaderWriterModifier rwm) {
         return new ValueReaderLocator(rwp, rwm);
     }
@@ -168,7 +168,7 @@ public class ValueReaderLocator
         }
         return new ValueReaderLocator(this, _readerProvider, rwm);
     }
-    
+
     public ValueReaderLocator perOperationInstance(JSONReader r, int features) {
         return new ValueReaderLocator(this, features & CACHE_FLAGS, r);
     }
@@ -188,7 +188,7 @@ public class ValueReaderLocator
     /* Public API, operations
     /**********************************************************************
      */
-    
+
     /**
      * Method used during deserialization to find handler for given
      * non-generic type: will first check for already resolved (and cached) readers
@@ -295,10 +295,34 @@ public class ValueReaderLocator
     }
 
     protected ValueReader enumReader(Class<?> enumType) {
+        // Call pojoDefinitionForDeserialization so that the annotation support extension can get custom names for
+        // enum values
+        POJODefinition def = null;
+        if (_readerModifier != null) {
+            def = _readerModifier.pojoDefinitionForDeserialization(_readContext, enumType);
+        }
+        Map<String, Object> byName =
+                JSON.Feature.ACCEPT_CASE_INSENSITIVE_ENUMS.isEnabled(_features)
+                    ? new TreeMap<String, Object>(String.CASE_INSENSITIVE_ORDER)
+                    // Note: we might want to retain declaration order with LHM in future
+                    // for error reporting; but not needed yet
+                    : new HashMap<String, Object>();
         Object[] enums = enumType.getEnumConstants();
-        Map<String,Object> byName = new HashMap<String,Object>();
-        for (Object e : enums) {
-            byName.put(e.toString(), e);
+        if (def == null) {
+            for (Object e : enums) {
+                byName.put(e.toString(), e);
+            }
+        } else {
+            for (POJODefinition.Prop e : def.getProperties()) {
+                if (e.field != null && e.field.isEnumConstant()) {
+                    try {
+                        byName.put(e.name, e.field.get(null));
+                    } catch (IllegalAccessException ex) {
+                        // Don't believe that this should be possible, but raise it up just in case
+                        throw new RuntimeException(ex);
+                    }
+                }
+            }
         }
         return new EnumReader(enumType, enums, byName);
     }
@@ -432,6 +456,7 @@ public class ValueReaderLocator
                 longCtor.setAccessible(true);
             }
         }
+        final boolean caseInsensitive = JSON.Feature.ACCEPT_CASE_INSENSITIVE_PROPERTIES.isEnabled(_features);
 
         final List<POJODefinition.Prop> rawProps = beanDef.getProperties();
         final int len = rawProps.size();
@@ -441,7 +466,10 @@ public class ValueReaderLocator
         if (len == 0) {
             propMap = Collections.emptyMap();
         } else {
-            propMap = new HashMap<String, BeanPropertyReader>();
+            propMap = caseInsensitive
+                    ? new TreeMap<String, BeanPropertyReader>(String.CASE_INSENSITIVE_ORDER)
+                    // 13-May-2021, tatu: Let's retain ordering here:
+                    : new LinkedHashMap<String, BeanPropertyReader>();
             final boolean useFields = JSON.Feature.USE_FIELDS.isEnabled(_features);
             for (int i = 0; i < len; ++i) {
                 POJODefinition.Prop rawProp = rawProps.get(i);
@@ -476,7 +504,9 @@ public class ValueReaderLocator
                 //   we must link via name of primary property, unfortunately:
                 if (rawProp.hasAliases()) {
                     if (aliasMapping == null) {
-                        aliasMapping = new HashMap<String, String>();
+                        aliasMapping = caseInsensitive
+                                ? new TreeMap<String, String>(String.CASE_INSENSITIVE_ORDER)
+                                : new HashMap<String, String>();
                     }
                     for (String alias : rawProp.aliases()) {
                         aliasMapping.put(alias, rawProp.name);
